@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_cloudwatch._jsii
@@ -21,9 +21,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-codedeploy",
-    "1.62.0",
+    "1.64.1",
     __name__[0:-6],
-    "aws-codedeploy@1.62.0.jsii.tgz",
+    "aws-codedeploy@1.64.1.jsii.tgz",
 )
 
 __all__ = [
